# Setting up a Gitea code hosting platform

Gitea is a self-hosted Git-based Code Hosting Platform and a nice alternative to Github 
and other proprietary services.
You can use this Ansible Playbook to host your own Code Hosting Platform under your own control.

This setup offers:

* Gitea 
* PostgreSQL backend

## Prerequisites

* A Rhel8 or CentOs8 machine.
* A publicly available FQDN: (preferred)
* The following collections need to be installed
  - comminuty.postgresql
  - ansible.posix

```
git.example.org.	300	IN	A	1.2.3.4
```

## Deploy gitea

```
$ cd ansible-deploy-gitea
```

Prepare a *vars/all.yml* file (you can use *vars/all.yml.example* as reference):

```
# vars/all.yml
gitea_fqdn: git.example.org
gitea_db: giteadb
gitea_db_user: giteadbuser
gitea_db_passwd: <the password>
gitea_version: 1.18.5
```

Run the playbook with the host(s) to deploy as extra_vars :

```
$ ansible-playbook deploy_gitea.yml -e instances=<hostname> -i <path_to_inventory> 
```

When done rush to http://<your hostname>:3000/  
First one to create an account gets to be an admin!

References
----------
* https://docs.gitea.io/en-us/install-from-binary/
* https://docs.gitea.io/en-us/linux-service/
* https://dl.gitea.io/gitea/1.18.5/
* https://docs.ansible.com/ansible/latest/modules/postgresql_db_module.html
* https://docs.ansible.com/ansible/latest/modules/postgresql_user_module.html
